@@ -10,8 +10,8 @@
 #' @examples
 #' x <- trbl_interval(
 #'   ~chrom, ~start, ~end,
-#'   'chr1',      0,      10,
-#'   'chr1',      75,    100
+#'   'chr1', 0,      10,
+#'   'chr1', 75,     100
 #' )
 #'
 #' genome <- trbl_genome(
@@ -23,18 +23,18 @@
 #'
 #' genome <- trbl_genome(
 #'    ~chrom,  ~size,
-#'    "chr1", 500,
-#'    "chr2", 600,
-#'    "chr3", 800
+#'    'chr1',  500,
+#'    'chr2',  600,
+#'    'chr3',  800
 #' )
 #'
 #' x <- trbl_interval(
 #'    ~chrom, ~start, ~end,
-#'    "chr1", 100,    300,
-#'    "chr1", 200,    400,
-#'    "chr2",  0,      100,
-#'    "chr2", 200,    400,
-#'    "chr3", 500,    600
+#'    'chr1', 100,    300,
+#'    'chr1', 200,    400,
+#'    'chr2', 0,      100,
+#'    'chr2', 200,    400,
+#'    'chr3', 500,    600
 #' )
 #'
 #' # intervals not covered by x
@@ -43,27 +43,25 @@
 #' @export
 bed_complement <- function(x, genome) {
 
-  if (!is.tbl_interval(x)) x <- tbl_interval(x)
-  if (!is.tbl_genome(genome)) genome <- tbl_genome(genome)
+  if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
+  if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
 
   res <- bed_merge(x)
 
   # non-overlapping chroms
-  chroms_no_overlaps <- anti_join(genome, res, by = 'chrom')
+  chroms_no_overlaps <- anti_join(genome, res, by = "chrom")
   chroms_no_overlaps <- mutate(chroms_no_overlaps, start = 0)
   chroms_no_overlaps <- select(chroms_no_overlaps, chrom, start, end = size)
 
   # remove rows from x that are not in genome
-  res <- semi_join(res, genome, by = 'chrom')
+  res <- semi_join(res, genome, by = "chrom")
 
   res <- group_by(res, chrom)
 
   res <- complement_impl(res, genome)
-  res <- as_tibble(res)
 
   res <- bind_rows(res, chroms_no_overlaps)
-  res <- arrange(res, chrom, start)
+  res <- bed_sort(res)
 
   res
 }
-
