@@ -11,6 +11,7 @@
 #' @return [tbl_interval()]
 #'
 #' @family randomizing operations
+#'
 #' @seealso \url{http://bedtools.readthedocs.org/en/latest/content/tools/random.html}
 #'
 #' @examples
@@ -31,12 +32,13 @@
 #' bed_random(genome, length = 500, n = 500, seed = 10104)
 #'
 #' @export
-bed_random <- function(genome, length = 1000, n = 1e6, sort_by = c('chrom', 'start'), seed = 0) {
+bed_random <- function(genome, length = 1000, n = 1e6,
+                       sort_by = c("chrom", "start"), seed = 0) {
 
-  if (!is.tbl_genome(genome)) genome <- tbl_genome(genome)
+  if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
 
-  if(!all(genome$size > length))
-    stop('`length` must be greater than all chrom sizes', call. = FALSE)
+  if (!all(genome$size > length))
+    stop("`length` must be greater than all chrom sizes", call. = FALSE)
 
   out <- random_impl(genome, length, n, seed)
 
