@@ -6,31 +6,27 @@
 #'
 #' @family interval statistics
 #'
-#' @return If `detail = FALSE`, a [tbl_interval()] that summarizes
-#'  calculated `.reldist` values with the following columns:
+#' @return
+#' If `detail = FALSE`, a [tbl_interval()] that summarizes
+#' calculated `.reldist` values with the following columns:
+#'
 #'   - `.reldist` relative distance metric
 #'   - `.counts` number of metric observations
 #'   - `.total` total observations
 #'   - `.freq` frequency of observation
 #'
-#'   If `detail = TRUE`, a new `.reldist` column reports the relative
-#'   distance for each input `x` interval.
+#' If `detail = TRUE`, the `.reldist` column reports the relative
+#' distance for each input `x` interval.
 #'
 #' @template stats
 #'
 #' @seealso \url{http://bedtools.readthedocs.io/en/latest/content/tools/reldist.html}
 #'
 #' @examples
-#' x <- trbl_interval(
-#'   ~chrom,   ~start,    ~end,
-#'   "chr1",    75,       125
-#' )
+#' genome <- read_genome(valr_example('hg19.chrom.sizes.gz'))
 #'
-#' y <- trbl_interval(
-#'   ~chrom,   ~start,    ~end,
-#'   "chr1",    50,       100,
-#'   "chr1",    100,       150
-#' )
+#' x <- bed_random(genome, seed = 1010486)
+#' y <- bed_random(genome, seed = 9203911)
 #'
 #' bed_reldist(x, y)
 #'
@@ -39,17 +35,17 @@
 #' @export
 bed_reldist <- function(x, y, detail = FALSE) {
 
-  if (!is.tbl_interval(x)) x <- tbl_interval(x)
-  if (!is.tbl_interval(y)) y <- tbl_interval(y)
+  if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
+  if (!is.tbl_interval(y)) y <- as.tbl_interval(y)
 
   x <- group_by(x, chrom, add = TRUE)
   y <- group_by(y, chrom, add = TRUE)
 
-  res <- reldist_impl(x, y)
+  res <- dist_impl(x, y, distcalc = "reldist")
 
   if (detail) return(res)
 
-  res[['.reldist']] <- floor(res[['.reldist']] * 100) / 100
+  res[[".reldist"]] <- floor(res[[".reldist"]] * 100) / 100
   nr <- nrow(res)
   res <- group_by(res, .reldist)
   res <- summarize(res,
@@ -58,5 +54,3 @@ bed_reldist <- function(x, y, detail = FALSE) {
                    .freq = .counts / .total)
   res
 }
-
-
