@@ -1,4 +1,4 @@
-#' Subtract intervals.
+#' Subtract two sets of intervals.
 #'
 #' Subtract `y` intervals from `x` intervals.
 #'
@@ -9,6 +9,7 @@
 #' @template groups
 #'
 #' @family multiple set operations
+#'
 #' @seealso \url{http://bedtools.readthedocs.io/en/latest/content/tools/subtract.html}
 #'
 #' @examples
@@ -26,21 +27,21 @@
 #'
 #' x <- trbl_interval(
 #'  ~chrom, ~start, ~end,
-#'  "chr1", 100,    200,
-#'  "chr1", 250,    400,
-#'  "chr1", 500,    600,
-#'  "chr1", 1000,   1200,
-#'  "chr1", 1300,   1500
+#'  'chr1', 100,    200,
+#'  'chr1', 250,    400,
+#'  'chr1', 500,    600,
+#'  'chr1', 1000,   1200,
+#'  'chr1', 1300,   1500
 #' )
 #'
 #' y <- trbl_interval(
 #'  ~chrom, ~start, ~end,
-#'  "chr1", 150,    175,
-#'  "chr1", 510,    525,
-#'  "chr1", 550,    575,
-#'  "chr1", 900,    1050,
-#'  "chr1", 1150,   1250,
-#'  "chr1", 1299,   1501
+#'  'chr1', 150,    175,
+#'  'chr1', 510,    525,
+#'  'chr1', 550,    575,
+#'  'chr1', 900,    1050,
+#'  'chr1', 1150,   1250,
+#'  'chr1', 1299,   1501
 #' )
 #'
 #' bed_subtract(x, y)
@@ -50,8 +51,8 @@
 #' @export
 bed_subtract <- function(x, y, any = FALSE) {
 
-  if (!is.tbl_interval(x)) x <- tbl_interval(x)
-  if (!is.tbl_interval(y)) y <- tbl_interval(y)
+  if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
+  if (!is.tbl_interval(y)) y <- as.tbl_interval(y)
 
   x <- group_by(x, chrom, add = TRUE)
   y <- group_by(y, chrom, add = TRUE)
@@ -64,7 +65,7 @@ bed_subtract <- function(x, y, any = FALSE) {
   if (any) {
     # collect and return x intervals without overlaps
     res <- bed_intersect(x, y)
-    colspec <- c('chrom', 'start' = 'start.x', 'end' = 'end.x')
+    colspec <- c("chrom", "start" = "start.x", "end" = "end.x")
     anti <- anti_join(x, res, by = colspec)
 
     return(anti)
@@ -72,7 +73,7 @@ bed_subtract <- function(x, y, any = FALSE) {
 
   res <- subtract_impl(x, y)
   res <- bind_rows(res, res_no_y)
-  res <- arrange(res, chrom, start)
+  res <- bed_sort(res)
 
   res
 }
