@@ -4,7 +4,9 @@
 #' strand. I.e., the first introns for `+` and `-` strand genes both have `score`
 #' values of `1`.
 #'
-#' @param x [tbl_interval] in BED12 format
+#' @param x [tbl_interval()] in BED12 format
+#'
+#' @family feature functions
 #'
 #' @examples
 #' x <- read_bed12(valr_example('mm9.refGene.bed.gz'))
@@ -32,7 +34,9 @@ create_introns <- function(x) {
 
 #' Create 5' UTR features.
 #'
-#' @param x [tbl_interval] in BED12 format
+#' @param x [tbl_interval()] in BED12 format
+#'
+#' @family feature functions
 #'
 #' @examples
 #' x <- read_bed12(valr_example('mm9.refGene.bed.gz'))
@@ -43,8 +47,8 @@ create_introns <- function(x) {
 create_utrs5 <- function(x) {
   res <- group_by(x, name)
   res <- mutate(res,
-                start = ifelse(strand == '+', start, cds_end),
-                end   = ifelse(strand == '+', cds_start, end))
+                start = ifelse(strand == "+", start, cds_end),
+                end   = ifelse(strand == "+", cds_start, end))
   res <- ungroup(res)
   res <- select(res, chrom:strand)
 
@@ -56,7 +60,9 @@ create_utrs5 <- function(x) {
 
 #' Create 3' UTR features.
 #'
-#' @param x [tbl_interval] in BED12 format
+#' @param x [tbl_interval()] in BED12 format
+#'
+#' @family feature functions
 #'
 #' @examples
 #' x <- read_bed12(valr_example('mm9.refGene.bed.gz'))
@@ -67,8 +73,8 @@ create_utrs5 <- function(x) {
 create_utrs3 <- function(x) {
   res <- group_by(x, name)
   res <- mutate(res,
-                start = ifelse(strand == '+', cds_end, start),
-                end   = ifelse(strand == '+', end, cds_start))
+                start = ifelse(strand == "+", cds_end, start),
+                end   = ifelse(strand == "+", end, cds_start))
   res <- ungroup(res)
   res <- select(res, chrom:strand)
 
@@ -77,3 +83,25 @@ create_utrs3 <- function(x) {
 
   res
 }
+
+#' Create transcription start site features.
+#'
+#' @param x [tbl_interval()] in BED format
+#'
+#' @family feature functions
+#'
+#' @examples
+#' x <- read_bed12(valr_example('mm9.refGene.bed.gz'))
+#'
+#' create_tss(x)
+#'
+#' @export
+create_tss <- function(x) {
+  res <- group_by(x, name)
+  res <- mutate(res,
+                start = ifelse(strand == "+", start, end - 1),
+                end   = ifelse(strand == "+", start + 1, end))
+  res <- ungroup(res)
+  res <- select(res, chrom:strand)
+  res
+}
