@@ -5,11 +5,11 @@ has_internet <- function() {
 }
 
 test_that("ucsc connection works", {
-  skip('run db tests manually.')
-  skip_if_not_installed('curl')
-  skip_if_not_installed('RMySQL')
+  skip("run db tests manually.")
+  skip_if_not_installed("curl")
+  skip_if_not_installed("RMySQL")
 
-  if(!has_internet()) skip('no internet connection')
+  if (!has_internet()) skip("no internet connection")
 
   skip_on_cran()
   skip_on_travis()
@@ -22,11 +22,11 @@ test_that("ucsc connection works", {
 })
 
 test_that("ensembl connection works", {
-  skip('run db tests manually.')
-  skip_if_not_installed('curl')
-  skip_if_not_installed('RMySQL')
+  skip("run db tests manually.")
+  skip_if_not_installed("curl")
+  skip_if_not_installed("RMySQL")
 
-  if (!has_internet()) skip('no internet connection')
+  if (!has_internet()) skip("no internet connection")
 
   skip_on_cran()
   skip_on_travis()
