@@ -1,4 +1,4 @@
-context('bed_merge')
+context("bed_merge")
 
 test_that("merge on 1 chrom", {
   bed_df <- tibble::tribble(
@@ -69,15 +69,15 @@ test_that("max_dist is a positive value", {
   expect_error(bed_merge(bed_df, max_dist = -1))
 })
 
-test_that("input groups are maintained in the output tbl issue #108",{
+test_that("input groups are maintained in the output tbl issue #108", {
 
   x <- tibble::tribble(
     ~chrom, ~start, ~end, ~group,
-    'chr1', 100,    200,  'A',
-    'chr1', 200,    400,  'A',
-    'chr1', 300,    500,  'A',
-    'chr1', 125,    175,  'C',
-    'chr1', 150,    200,  'B'
+    "chr1", 100,    200,  "A",
+    "chr1", 200,    400,  "A",
+    "chr1", 300,    500,  "A",
+    "chr1", 125,    175,  "C",
+    "chr1", 150,    200,  "B"
   )
 
   x <- arrange(x, chrom, start)
@@ -86,15 +86,15 @@ test_that("input groups are maintained in the output tbl issue #108",{
   expect_true(all(x$group %in% res$group))
 })
 
-test_that("intervals can be merged by strand",{
+test_that("intervals can be merged by strand", {
 
   x <- tibble::tribble(
     ~chrom, ~start, ~end, ~strand,
-    'chr1', 100,    200,  '+',
-    'chr1', 200,    400,  '+',
-    'chr1', 300,    500,  '+',
-    'chr1', 125,    175,  '-',
-    'chr1', 150,    200,  '-'
+    "chr1", 100,    200,  "+",
+    "chr1", 200,    400,  "+",
+    "chr1", 300,    500,  "+",
+    "chr1", 125,    175,  "-",
+    "chr1", 150,    200,  "-"
   )
 
   x <- group_by(x, strand)
@@ -106,13 +106,13 @@ test_that("summaries can be computed issue #132",{
 
   x <- tibble::tribble(
     ~chrom, ~start, ~end, ~value, ~strand,
-    "chr1", 1,      50,   1,      '+',
-    "chr1", 100,    200,  2,      '+',
-    "chr1", 150,    250,  3,      '-',
-    "chr2", 1,      25,   4,      '+',
-    "chr2", 200,    400,  5,      '-',
-    "chr2", 400,    500,  6,      '+',
-    "chr2", 450,    550,  7,      '+'
+    "chr1", 1,      50,   1,      "+",
+    "chr1", 100,    200,  2,      "+",
+    "chr1", 150,    250,  3,      "-",
+    "chr2", 1,      25,   4,      "+",
+    "chr2", 200,    400,  5,      "-",
+    "chr2", 400,    500,  6,      "+",
+    "chr2", 450,    550,  7,      "+"
   )
 
   res <- bed_merge(x, .value = sum(value))
@@ -124,13 +124,13 @@ test_that("multiple summaries can be computed issue #132",{
 
   x <- tibble::tribble(
     ~chrom, ~start, ~end, ~value, ~strand,
-    "chr1", 1,      50,   1,      '+',
-    "chr1", 100,    200,  2,      '+',
-    "chr1", 150,    250,  3,      '-',
-    "chr2", 1,      25,   4,      '+',
-    "chr2", 200,    400,  5,      '-',
-    "chr2", 400,    500,  6,      '+',
-    "chr2", 450,    550,  7,      '+'
+    "chr1", 1,      50,   1,      "+",
+    "chr1", 100,    200,  2,      "+",
+    "chr1", 150,    250,  3,      "-",
+    "chr2", 1,      25,   4,      "+",
+    "chr2", 200,    400,  5,      "-",
+    "chr2", 400,    500,  6,      "+",
+    "chr2", 450,    550,  7,      "+"
   )
 
   res <- bed_merge(x, .value = sum(value), .min = min(value))
@@ -142,9 +142,9 @@ test_that("multiple summaries can be computed issue #132",{
 test_that("contained intervals are merged issue #176", {
   x <- tibble::tribble(
     ~chrom, ~start, ~end,
-    'chr1',  1,     10,
-    'chr1',  2,     5,
-    'chr1',  7,     9
+    "chr1",  1,     10,
+    "chr1",  2,     5,
+    "chr1",  7,     9
   )
 
   res <- bed_merge(x)
@@ -154,11 +154,24 @@ test_that("contained intervals are merged issue #176", {
 test_that("is_merged identifies previously merged tbls", {
   x <- tibble::tribble(
     ~chrom, ~start, ~end,
-    'chr1',  1,     10,
-    'chr1',  2,     5,
-    'chr1',  7,     9
+    "chr1",  1,     10,
+    "chr1",  2,     5,
+    "chr1",  7,     9
   )
   expect_false(is_merged(x))
   res <- bed_merge(x)
   expect_true(is_merged(res))
 })
+
+test_that("bed_merge with spec returns start/end columns (issue #288)", {
+
+  x <- trbl_interval(
+    ~chrom, ~start, ~end, ~value,
+    "chr1", 100,    200,  100,
+    "chr1", 150,    250,  200
+  )
+
+  res <- bed_merge(x, .value = sum(value))
+  expect_true('start' %in% names(res))
+  expect_true('end' %in% names(res))
+})
