@@ -1,6 +1,6 @@
-context('bed_random')
+context("bed_random")
 
-genome <- read_genome(valr_example('hg19.chrom.sizes.gz'))
+genome <- read_genome(valr_example("hg19.chrom.sizes.gz"))
 
 # Seed for reproducible bed_random tests
 seed <- 1010486
@@ -20,14 +20,14 @@ test_that("all ends are less or equal to than chrom size", {
   len <- 1000
   res <- bed_random(genome, length = len, n = 1e4, seed = seed) %>%
     mutate(chrom = as.character(chrom)) %>%
-    left_join(genome, by = 'chrom')
+    left_join(genome, by = "chrom")
   expect_true(all(res$end <= res$size))
 })
 
 test_that("chrom sizes less than length throws an error", {
   genome <- tibble::tribble(
     ~chrom, ~size,
-    'chr1', 125
+    "chr1", 125
   )
   expect_error(bed_random(genome, seed = seed))
 })
